---
name: "✨ Feature request"
about: "Suggest a feature or improvement"
title: "[FEAT] <suggestion> for <module.component>"
labels: enhancement
assignees: ''

---

### Description

A clear description of the feature/improvement is and what **motivates** it.

### Implementation

A clear description of how you would like the feature to be implemented.
If possible, provide reference examples (*e.g.* repository, issue, paper, ...).

### Alternatives

A clear description of any alternative solutions you've considered.
